/**
 * Copyright (C) 2011 Ovea <dev@ovea.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.ovea.markup;

import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public final class MarkupAttributes {

    private final Map<String, Object> attributes = new ConcurrentHashMap<String, Object>();

    @SuppressWarnings({"unchecked"})
    public <T> T get(String key) {
        return (T) attributes.get(key);
    }

    public <T> T get(Class<T> key) {
        return this.<T>get(key.getSimpleName().toLowerCase());
    }

    public void set(String key, Object val) {
        if (val == null)
            attributes.remove(key);
        else
            attributes.put(key, val);
    }

    public <T> void set(Class<T> key, T val) {
        set(key.getSimpleName().toLowerCase(), val);
    }

    public boolean has(String key) {
        return attributes.containsKey(key);
    }

    public boolean has(Class<?> key) {
        return has(key.getSimpleName().toLowerCase());
    }

    public Map<String, ?> asMap() {
        return new HashMap<String, Object>(attributes);
    }
}
